#[non_exhaustive]pub enum Error {
Show 14 variants
PortMissing(String),
Decode {
as_json: String,
error: String,
},
Jsonify(String),
Channel(String),
Component(String),
NoData,
PayloadError(PacketError),
UnexpectedDone,
ContextKey(String),
BadJson(Value),
StreamMapError(String, String),
StreamMapMissing(String),
Signature(String, String),
Coersion {
value: Value,
desired: Type,
},
}Expand description
Errors originating from WASM components.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
PortMissing(String)
Thrown when a user attempts to retrieve a stream for a port that doesn’t exist.
Decode
Error deserializing payload.
Jsonify(String)
Error converting payload into JSON.
Channel(String)
Error communicating over a stream or channel.
Component(String)
General error to wrap other errors.
NoData
Payload was successful but no data was provided.
PayloadError(PacketError)
An error that wraps a PayloadError.
UnexpectedDone
Thrown when a user attempts to use a signal when they expected a payload.
ContextKey(String)
Returned when an operation attempts to retrieve a configuration item that doesn’t exist or decoding fails.
BadJson(Value)
Returned when trying to decode a non-JSON object into crate::RuntimeConfig.
StreamMapError(String, String)
Couldn’t retrieve a complete set of packets from a crate::StreamMap
StreamMapMissing(String)
Couldn’t retrieve a complete set of packets from a crate::StreamMap
Signature(String, String)
Coersion
Implementations